@@ -1,4 +1,4 @@
-ALTER TABLE %allsongstables ADD COLUMN fingerprint TEXT DEFAULT '';
+ALTER TABLE %allsongstables ADD COLUMN fingerprint TEXT;
 
 ALTER TABLE %allsongstables ADD COLUMN lastseen INTEGER NOT NULL DEFAULT -1;
 
