@@ -23,7 +23,7 @@
 #include <QtGlobal>
 #include <QString>
 
-#include "core/shared_ptr.h"
+#include "includes/shared_ptr.h"
 
 class TaskManager;
 
