@@ -23,11 +23,13 @@
 #include <QUrl>
 #include <QRegularExpression>
 
-#include "core/shared_ptr.h"
+#include "includes/shared_ptr.h"
 #include "core/networkaccessmanager.h"
 #include "lyricssearchrequest.h"
 #include "songlyricscomlyricsprovider.h"
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace {
 constexpr char kUrl[] = "https://www.songlyrics.com/";
 constexpr char kStartTag[] = "<p[^>]*>";
@@ -35,12 +37,12 @@ constexpr char kEndTag[] = "<\\/p>";
 constexpr char kLyricsStart[] = "<p id=\"songLyricsDiv\"[^>]+>";
 }  // namespace
 
-SongLyricsComLyricsProvider::SongLyricsComLyricsProvider(SharedPtr<NetworkAccessManager> network, QObject *parent)
-    : HtmlLyricsProvider(QStringLiteral("songlyrics.com"), true, QLatin1String(kStartTag), QLatin1String(kEndTag), QLatin1String(kLyricsStart), false, network, parent) {}
+SongLyricsComLyricsProvider::SongLyricsComLyricsProvider(const SharedPtr<NetworkAccessManager> network, QObject *parent)
+    : HtmlLyricsProvider(u"songlyrics.com"_s, true, QLatin1String(kStartTag), QLatin1String(kEndTag), QLatin1String(kLyricsStart), false, network, parent) {}
 
 QUrl SongLyricsComLyricsProvider::Url(const LyricsSearchRequest &request) {
 
-  return QUrl(QLatin1String(kUrl) + StringFixup(request.artist) + QLatin1Char('/') + StringFixup(request.title) + QLatin1String("-lyrics/"));
+  return QUrl(QLatin1String(kUrl) + StringFixup(request.artist) + QLatin1Char('/') + StringFixup(request.title) + "-lyrics/"_L1);
 
 }
 
@@ -48,17 +50,17 @@ QString SongLyricsComLyricsProvider::StringFixup(QString text) {
 
   Q_ASSERT(QThread::currentThread() != qApp->thread());
 
-  static const QRegularExpression regex_illegal_characters(QStringLiteral("[^\\w0-9\\- ]"));
-  static const QRegularExpression regex_multiple_whitespaces(QStringLiteral(" {2,}"));
-  static const QRegularExpression regex_multiple_dashes(QStringLiteral("(-)\\1+"));
+  static const QRegularExpression regex_illegal_characters(u"[^\\w0-9\\- ]"_s);
+  static const QRegularExpression regex_multiple_whitespaces(u" {2,}"_s);
+  static const QRegularExpression regex_multiple_dashes(u"(-)\\1+"_s);
 
-  return text.replace(QLatin1Char('/'), QLatin1Char('-'))
-             .replace(QLatin1Char('\''), QLatin1Char('-'))
+  return text.replace(u'/', u'-')
+             .replace(u'\'', u'-')
              .remove(regex_illegal_characters)
-             .replace(regex_multiple_whitespaces, QStringLiteral(" "))
+             .replace(regex_multiple_whitespaces, u" "_s)
              .simplified()
-             .replace(QLatin1Char(' '), QLatin1Char('-'))
-             .replace(regex_multiple_dashes, QStringLiteral("-"))
+             .replace(u' ', u'-')
+             .replace(regex_multiple_dashes, u"-"_s)
              .toLower();
 
 }
