@@ -206,7 +206,9 @@ int main(int argc, char *argv[]) {
 
   QThread::currentThread()->setObjectName(u"Main"_s);
 
-  QGuiApplication::setWindowIcon(IconLoader::Load(u"strawberry"_s));
+  if (QGuiApplication::platformName() != "wayland"_L1) {
+    QGuiApplication::setWindowIcon(IconLoader::Load(u"strawberry"_s));
+  }
 
 #if defined(USE_BUNDLE)
   qLog(Debug) << "Looking for resources in" << QCoreApplication::libraryPaths();
@@ -342,6 +344,11 @@ int main(int argc, char *argv[]) {
 
   int ret = QCoreApplication::exec();
 
+#ifdef __MINGW32__
+  // Workaround crash on exit with win32 threads
+  TerminateProcess(GetCurrentProcess(), 0);
+#endif
+
   return ret;
 
 }
