@@ -97,7 +97,7 @@ void MoodbarController::AsyncLoadComplete(MoodbarPipelinePtr pipeline, const QUr
 
   // Is this song still playing?
   PlaylistItemPtr current_item = player_->GetCurrentItem();
-  if (current_item && current_item->Url() != url) {
+  if (current_item && current_item->OriginalUrl() != url) {
     return;
   }
   // Did we stop the song?
