@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2013-2024, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2013-2025, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,6 +72,11 @@ static const QRegularExpression kRegex_ALSA_PCM_Dev(u"^.*:.*DEV=.*"_s);
 #endif
 }  // namespace
 
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Warray-bounds"
+#endif
+
 BackendSettingsPage::BackendSettingsPage(SettingsDialog *dialog, const SharedPtr<Player> player, const SharedPtr<DeviceFinders> device_finders, QWidget *parent)
     : SettingsPage(dialog, parent),
       ui_(new Ui_BackendSettingsPage),
@@ -125,8 +130,19 @@ void BackendSettingsPage::Load() {
   Settings s;
   s.beginGroup(kSettingsGroup);
 
-  output_current_ = s.value(kOutput, QString()).toString();
-  device_current_ = s.value(kDevice, QVariant());
+  if (s.contains(kOutputU)) {
+    output_current_ = s.value(kOutputU).toString();
+  }
+  else if (s.contains(kOutput)) {
+    output_current_ = s.value(kOutput).toString();
+  }
+
+  if (s.contains(kDeviceU)) {
+    device_current_ = s.value(kDeviceU);
+  }
+  else if (s.contains(kDevice)) {
+    device_current_ = s.value(kDevice);
+  }
 
 #ifdef HAVE_ALSA
   ui_->lineedit_device->show();
@@ -162,6 +178,8 @@ void BackendSettingsPage::Load() {
 
   ui_->checkbox_bs2b->setChecked(s.value(kBS2B, false).toBool());
 
+  ui_->checkbox_playbin3->setChecked(s.value(kPlaybin3, true).toBool());
+
   ui_->checkbox_http2->setChecked(s.value(kHTTP2, false).toBool());
   ui_->checkbox_strict_ssl->setChecked(s.value(kStrictSSL, false).toBool());
 
@@ -389,6 +407,20 @@ void BackendSettingsPage::Save() {
   Settings s;
   s.beginGroup(kSettingsGroup);
 
+  if (s.contains(kEngineU)) {
+    s.remove(kEngineU);
+  }
+  if (s.contains(kEngine)) {
+    s.remove(kEngine);
+  }
+
+  if (s.contains(kOutputU)) {
+    s.remove(kOutputU);
+  }
+  if (s.contains(kDeviceU)) {
+    s.remove(kDeviceU);
+  }
+
   s.setValue(kOutput, output_name);
   s.setValue(kDevice, device_value);
 
@@ -410,6 +442,8 @@ void BackendSettingsPage::Save() {
 
   s.setValue(kBS2B, ui_->checkbox_bs2b->isChecked());
 
+  s.setValue(kPlaybin3, ui_->checkbox_playbin3->isChecked());
+
   s.setValue(kHTTP2, ui_->checkbox_http2->isChecked());
   s.setValue(kStrictSSL, ui_->checkbox_strict_ssl->isChecked());
 
@@ -732,3 +766,7 @@ void BackendSettingsPage::BufferDefaults() {
   ui_->spinbox_high_watermark->setValue(kDefaultBufferHighWatermark);
 
 }
+
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
