@@ -35,7 +35,7 @@ class SmartPlaylistsView : public QListView {
   ~SmartPlaylistsView();
 
  protected:
-  void selectionChanged(const QItemSelection&, const QItemSelection&) override;
+  void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected) override;
   void contextMenuEvent(QContextMenuEvent *e) override;
 
  Q_SIGNALS:
