@@ -36,7 +36,7 @@
 #include <QIcon>
 #include <QPixmap>
 
-#include "core/shared_ptr.h"
+#include "includes/shared_ptr.h"
 #include "core/song.h"
 #include "collection/collectionmodel.h"
 #include "streamingsearchview.h"
@@ -96,11 +96,7 @@ class StreamingSearchModel : public QStandardItemModel {
   QMap<ContainerKey, QStandardItem*> containers_;
 };
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 inline size_t qHash(const StreamingSearchModel::ContainerKey &key) {
-#else
-inline uint qHash(const StreamingSearchModel::ContainerKey &key) {
-#endif
   return qHash(key.group_[0]) ^ qHash(key.group_[1]) ^ qHash(key.group_[2]);
 }
 
