@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2024, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2024-2025, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #define TAGREADERREQUEST_H
 
 #include <QString>
+#include <QUrl>
 
 #include "includes/shared_ptr.h"
 #include "tagreaderreply.h"
@@ -28,8 +29,10 @@
 class TagReaderRequest {
  public:
   explicit TagReaderRequest(const QString &_filename);
+  explicit TagReaderRequest(const QUrl &_url, const QString &_filename);
   virtual ~TagReaderRequest();
   QString filename;
+  QUrl url;
   TagReaderReplyPtr reply;
 };
 
