@@ -33,7 +33,11 @@
 #include "transcoderoptionsmp3.h"
 #include "ui_transcoderoptionsmp3.h"
 
-const char *TranscoderOptionsMP3::kSettingsGroup = "Transcoder/lamemp3enc";
+#include "core/settings.h"
+
+namespace {
+constexpr char kSettingsGroup[] = "Transcoder/lamemp3enc";
+}
 
 TranscoderOptionsMP3::TranscoderOptionsMP3(QWidget *parent) : TranscoderOptionsInterface(parent), ui_(new Ui_TranscoderOptionsMP3) {
 
@@ -50,8 +54,8 @@ TranscoderOptionsMP3::~TranscoderOptionsMP3() {
 
 void TranscoderOptionsMP3::Load() {
 
-  QSettings s;
-  s.beginGroup(kSettingsGroup + settings_postfix_);
+  Settings s;
+  s.beginGroup(QLatin1String(kSettingsGroup) + settings_postfix_);
 
   if (s.value("target", 1).toInt() == 0) {
     ui_->target_quality->setChecked(true);
@@ -72,8 +76,8 @@ void TranscoderOptionsMP3::Load() {
 
 void TranscoderOptionsMP3::Save() {
 
-  QSettings s;
-  s.beginGroup(kSettingsGroup + settings_postfix_);
+  Settings s;
+  s.beginGroup(QLatin1String(kSettingsGroup) + settings_postfix_);
 
   s.setValue("target", ui_->target_quality->isChecked() ? 0 : 1);
   s.setValue("quality", ui_->quality_spinbox->value());
