@@ -23,6 +23,6 @@
 ClickableLabel::ClickableLabel(QWidget *parent) : QLabel(parent) {}
 
 void ClickableLabel::mousePressEvent(QMouseEvent *event) {
-  emit Clicked();
+  Q_EMIT Clicked();
   QLabel::mousePressEvent(event);
 }
