@@ -32,15 +32,12 @@
 #include "sliderslider.h"
 
 class QTimer;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 class QEnterEvent;
-#else
-class QEvent;
-#endif
 class QPaintEvent;
 class QMouseEvent;
 class QWheelEvent;
 class QContextMenuEvent;
+class QEvent;
 
 class VolumeSlider : public SliderSlider {
   Q_OBJECT
@@ -51,16 +48,12 @@ class VolumeSlider : public SliderSlider {
   void HandleWheel(const int delta);
 
  protected:
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-  void enterEvent(QEnterEvent*) override;
-#else
-  void enterEvent(QEvent*) override;
-#endif
-  void leaveEvent(QEvent*) override;
-  void paintEvent(QPaintEvent*) override;
-  virtual void paletteChange(const QPalette&);
-  void slideEvent(QMouseEvent*) override;
-  void contextMenuEvent(QContextMenuEvent*) override;
+  void enterEvent(QEnterEvent *e) override;
+  void leaveEvent(QEvent *e) override;
+  void paintEvent(QPaintEvent *e) override;
+  virtual void paletteChange(const QPalette &palette);
+  void slideEvent(QMouseEvent *e) override;
+  void contextMenuEvent(QContextMenuEvent *e) override;
   void mousePressEvent(QMouseEvent*) override;
   void wheelEvent(QWheelEvent *e) override;
 
